**********************************************************************
* This is the push pull output transformer file
* for valve amplifiers.
*
* Americans please note that Raa (Resistance Anode to Anode) is equiverlent to
* your Rpp (Resistance Plate to Plate)
*
* Formula taken from the electronics designers handbook 1957 4-10
*
* Raa = Rp1 + Rp2 + 4(Rl+Ro)(Np/Ns)^2
*
* Np  = Number of turns in one-half primary winding
* Ns  = Number of turns in secondry winding
* Rp1 = resistance of primary winding connected to V1
* Rp2 = resistance of primary winding connected to V2
* Rl  = resistance of load on the secondry winding
* Ro  = resistance of secondry winding
*
* Neglecting transformer resistance we can simplify to
*
* Raa = 4Rl(Np/Ns)^2
*
* I have used simplified formulas, and chosen winding resistances that 
* tie to the winding resistances of the push pull output transformers 
* on the Sowter transformers website. These models have been tested with
* large number of simulations of Ampeg, Gibson, Hiwatt, Marshall, Laney, 
* Selmar and Kelly guitar amplifiers. 
*
* The output valves include the following combinations
*
* 1, 2 and 3 pairs of 6550A's (100, 200 and 300 Watts output)
* 1 and 2 pairs of EL34's     (50, 70, 100 and 152 Watts output) 
* 1 and 2 pairs of 7027A's    (50, 74, 100 and 158 Watts output)
*
* Netlist (c)2006 Suusi Malcolm-Brown feel free to copy and use for any reason
* excepting spam 
*
* Feedback to Suusi Malcolm-Brown smalcolmbrown@yahoo.co.uk
*
**********************************************************************
*
*	16 and 8 ohm output
*
* This file is couples to pushpull.asy
* 
*   1   L1    2   L2    3
*   |  _____  |  _____  |
*   --|_____|---|_____|--
*      
*      _____     _____  
*   --|_____|---|_____|--
*   |         |         |
*   4  L3     5   L4     6
*
.SUBCKT pushpull 1 2 3 4 5 6
.param La = (Raa/(8*4))
.param Lb = 1
.Param Lc = 0.18
.param Ra1 = Raa/50
L1 1 2 {La} Rser={Ra1} Rpar=1Meg Cpar=240p
L2 2 3 {La} Rser={Ra1} Rpar=1Meg Cpar=240p
L3 4 5 {Lb} Rser=0.22 Rpar=1Meg 
L4 5 6 {Lc} Rser=0.08 Rpar=1Meg 
K1 L1 L2 L3 L4 0.995
.ENDS
* 
**********************************************************************
*
*	16 ohm output impedence
*
* This file is couples to pushpull_16.asy 
*
*   1   L1    2   L2    3
*   |  _____  |  _____  |
*   --|_____|---|_____|--
*      
*           _____    
*        --|_____|--
*        |         |
*        4   L3    5
*
.SUBCKT pushpull_16 1 2 3 4 5
.param La = (Raa/(16*4))
.param Lb = 1
.param Ra1 = Raa/50
L1 1 2 {La} Rser={Ra1} Rpar=1Meg Cpar=240p
L2 2 3 {La} Rser={Ra1} Rpar=1Meg Cpar=240p
L3 4 5 {lb} Rser=0.22 Rpar=1Meg 
K1 L1 L2 L3 0.995
.ENDS
* 
**********************************************************************
*
*	8 ohm output impedence
*
* This file is couples to pushpull_8.asy
*
*   1   L1    2   L2    3
*   |  _____  |  _____  |
*   --|_____|---|_____|--
*      
*           _____    
*        --|_____|--
*        |         |
*        4   L3    5
*
.SUBCKT pushpull_8 1 2 3 4 5
.param La = (Raa/(8*4))
.param Lb = 1
.param Ra1 = Raa/50
L1 1 2 {La} Rser={Ra1} Rpar=1Meg Cpar=240p
L2 2 3 {La} Rser={Ra1} Rpar=1Meg Cpar=240p
L3 4 5 {lb} Rser=0.22 Rpar=1Meg 
K1 L1 L2 L3 0.995
.ENDS
*
**********************************************************************
* 
*	A generic pushpull output transformer allowing the user 
*   to define custom output impedenced.   
*
* This file is couples to pushpull_generic.asy
*
*
*   1   L1    2   L2    3
*   |  _____  |  _____  |
*   --|_____|---|_____|--
*      
*           _____    
*        --|_____|--
*        |         |
*        4   L3    5
*
.SUBCKT pushpull_A 1 2 3 4 5
.param La = (Raa/(Rl*4))
.param Lb = 1
.param Ra1 = Raa/50
L1 1 2 {La} Rser={Ra1} Rpar=1Meg Cpar=240p
L2 2 3 {La} Rser={Ra1} Rpar=1Meg Cpar=240p
L3 4 5 {Lb} Rser=0.22 Rpar=1Meg 
K1 L1 L2 L3 1
.ENDS
*
**********************************************************************
*
